@@ -7,14 +7,11 @@ use {
 
 #[derive(Accounts)]
 pub struct CloseMintManagerCtx<'info> {
-    #[account(constraint = mint_manager.token_managers == 0 @ ErrorCode::OutstandingTokens)]
+    #[account(mut, constraint = mint_manager.token_managers == 0 @ ErrorCode::OutstandingTokens, close = freeze_authority)]
     pub mint_manager: Account<'info, MintManager>,
-    #[account(mut,
-        constraint = mint.freeze_authority.unwrap() == mint_manager.key() @ ErrorCode::InvalidFreezeAuthority,
-        close = freeze_authority,
-    )]
+    #[account(mut, constraint = mint.freeze_authority.expect("No freeze authority") == mint_manager.key() @ ErrorCode::InvalidFreezeAuthority)]
     pub mint: Account<'info, Mint>,
-    #[account(constraint = mint_manager.initializer == freeze_authority.key() @ ErrorCode::InvalidFreezeAuthority)]
+    #[account(constraint = mint_manager.initializer == freeze_authority.key() @ ErrorCode::InvalidInitializer)]
     pub freeze_authority: Signer<'info>,
     pub payer: Signer<'info>,
     pub token_program: Program<'info, Token>,
@@ -28,7 +25,7 @@ pub fn handler(ctx: Context<CloseMintManagerCtx>) -> Result<()> {
 
     // set freeze authority of mint back to original
     let cpi_accounts = SetAuthority {
-        account_or_mint: ctx.accounts.freeze_authority.to_account_info(),
+        account_or_mint: ctx.accounts.mint.to_account_info(),
         current_authority: ctx.accounts.mint_manager.to_account_info(),
     };
     let cpi_program = ctx.accounts.token_program.to_account_info();
